#!/usr/bin/perl

use strict;
use Test;


# use a BEGIN block so we print our plan before loading modules
BEGIN { plan tests => 1 }


# Check MusicBrainz::DiscID loads ok
use MusicBrainz::DiscID;
ok(1);


exit;
