#!/usr/bin/perl
#
# Check that the POD documentation is Ok
#

use strict;
use Test::More;
eval "use Test::Pod 1.00";
plan skip_all => "Test::Pod 1.00 required for testing POD" if $@;

all_pod_files_ok();
